@@ -4,10 +4,19 @@ use Types::Standard qw( InstanceOf );
 use Encode 'decode';
 
 has tx => (
-    required => 1, is => 'ro',
-    isa => InstanceOf['Mojo::Transaction::HTTP'] );
+    required => 0,
+    is => 'ro',
+    isa => InstanceOf['Mojo::Transaction::HTTP']
+);
 
-sub dom {
+has dom => (
+    required => 0,
+    isa => InstanceOf['Mojo::DOM'],
+    is => 'lazy',
+    builder => 1,
+);
+
+sub _build_dom {
     my $tx = $_[0]->tx;
     my $dom = $tx->result->dom;
 
